.. anfema-django-utils documentation master file, created by
   sphinx-quickstart on Tue May 17 17:56:16 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to anfema-django-utils's documentation!
===============================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. autosummary::
   :toctree: _autosummary
   :template: custom-module-template.rst
   :recursive:

   anfema_django_utils.apps
   anfema_django_utils.db
   anfema_django_utils.caching


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
